@@ -9,7 +9,7 @@
 #ifndef KEYCHAIN_H
 #define KEYCHAIN_H
 
-#include "qkeychain_export.h"
+#include <qkeychain_export.h>
 
 #include <QtCore/QObject>
 #include <QtCore/QString>
